@@ -24,6 +24,21 @@ import sys
 import re
 
 __author__ = 'Wangolo Joel (info@nmapper.com)'
-__version__ = '0.1.1'
-__last_modification__ = '2019/11/22'
+__version__ = '1.4.7'
+__last_modification__ = '2029/06/11'
 
+
+class NmapNotInstalledError(Exception):
+    """Exception raised when nmap is not installed"""
+    
+    def __init__(self, message="Nmap is either not installed or we couldn't locate nmap path Please ensure nmap is installed"):
+        self.message = message 
+        super().__init__(message)
+        
+class NmapXMLParserError(Exception):
+    """Exception raised when we can't parse the output"""
+    
+    def __init__(self, message="Unable to parse xml output"):
+        self.message = message 
+        super().__init__(message)
+        
